This folder contains the implementation of custom KL divergence layer.
This is a custom implementation and not a built-in layer in any deep learning framework.
It was developed specifically for [AD@L1 CMS paper](https://www.nature.com/articles/s42256-022-00441-3).

# Files

* `kl_layer.py`: contains the standalone implementation of the custom KL divergence layer
* `kl_layer.h`: contains the HLS implementation of KL layer


# Usage

`kl_layer.py` contains the example of how to use the KL layer.
To run do

```
python kl_layer.py
```
